//
//  CuadradoView.swift
//  CuadradoGira
//
//  Created by Santiago Pavón on 10/6/15.
//  Copyright (c) 2015 UPM. All rights reserved.
//

import UIKit

@IBDesignable
class CuadradoView: UIView {

    override func awakeFromNib() {
        addGestureRecognizer(UIPinchGestureRecognizer(target: self, action: "pinch:"))
        addGestureRecognizer(UIRotationGestureRecognizer(target: self, action: "rotate:"))
        addGestureRecognizer(UITapGestureRecognizer(target: self, action: "tap:"))

    }
    
    func pinch(sender:UIPinchGestureRecognizer) {
        let scale = sender.scale
        transform = CGAffineTransformScale(transform, scale, scale)
        //size *= scale
        sender.scale = 1
    }
    
    
    func rotate(sender:UIRotationGestureRecognizer) {
        transform = CGAffineTransformRotate(transform, sender.rotation)
        sender.rotation = 0
    }

    func tap(sender:UITapGestureRecognizer) {
        hole = !hole
    }
    
    @IBInspectable
    var size: Double = 100.0 {
        didSet {
            setNeedsDisplay()
        }
    }
    
    @IBInspectable
    var hole: Bool = false {
        didSet {
            setNeedsDisplay()
        }
    }
    
    @IBInspectable
    var fillColor: UIColor = UIColor.redColor() {
        didSet {
            setNeedsDisplay()
        }
    }
    
    override func drawRect(rect: CGRect)
    {
        let rect = CGRectMake(
            bounds.size.width/2 - CGFloat(size/2),
            bounds.size.height/2 - CGFloat(size/2),
            CGFloat(size),
            CGFloat(size))
        let path = UIBezierPath(roundedRect: rect, cornerRadius: CGFloat(size/20))
        
        UIBezierPath(ovalInRect: rect)
        
        if hole {
            let rect2 = CGRectMake(
                bounds.size.width/2 - CGFloat(size/4),
                bounds.size.height/2 - CGFloat(size/4),
                CGFloat(size/2),
                CGFloat(size/2))
            let path2 = UIBezierPath(roundedRect: rect2, cornerRadius: CGFloat(size/40))

            path.usesEvenOddFillRule = true
            path.appendPath(path2)
        }
        
        UIColor.blueColor().setStroke()
        fillColor.setFill()
        path.lineWidth = 3
        path.stroke()
        path.fill()
    }


}
